import java.util.Scanner;

/**
 * Aah, Rock, Paper, Scissors, ...: A classic!
 * We implement it, in part, to show that the TwoPlayerGame
 * interface is quite flexible.
 * Thought questions before looking at code:
 * - What is a move?
 * - When is it valid?
 * - When is the game over?
 */

public class RockPaperScissors implements TwoPlayerGame{

    public static final String[] MOVES = {"Rock", "Paper", "Scissors"};
    private boolean isGameOver;

    public RockPaperScissors() {
        isGameOver = false;
    }

    public String toString() {
        String s = "Moves: ";
        for (int move = 0; move < MOVES.length; move++) {
            s += "[" + move + ", " + MOVES[move] + "]";
        }
        return s;
    }

    public boolean isGameOver() {
        return isGameOver;
    }

    // removes matches from the specified pile
    public void makeMove(int p0, int p1) {
        System.out.println(MOVES[p0] + " vs. " + MOVES[p1]);
        if (p0 == p1) {
            System.out.println("Tie. Keep going.");
        } else {
            isGameOver = true;
        }
    }

    // Indices better be 0, 1, or 2!
    public boolean isValidMove(int p0, int p1) {
        return (0 <= p0) && (p0 < MOVES.length) && (0 <= p1) && (p1 < MOVES.length);
    }
    
    public static void main(String[] args) {
        RockPaperScissors game = new RockPaperScissors();
        Scanner scan = new Scanner(System.in);

        while (!game.isGameOver()) {
            System.out.println(game);

            System.out.print("Enter player 0's move: ");
            int p0Move = scan.nextInt();
            System.out.print("Enter player 1's move: ");
            int p1Move = scan.nextInt();

            while (!game.isValidMove(p0Move, p1Move)) {
                System.out.println("\nInvalid move! Try again");
                System.out.println(game);

                System.out.print("Enter player 0's move: ");
                p0Move = scan.nextInt();
                System.out.print("Enter player 1's move: ");
                p1Move = scan.nextInt();
            }

            game.makeMove(p0Move, p1Move);
        }

        System.out.println("Game Over");
        scan.close();
    }

}
